==> pegasus-merchandise-api-1.4.9-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuCategoryVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author Eric.Lou
 * @version $Id: JsTree.java, v 0.1 2015-07-30 16:50
 */
public class PcsSkuCategoryVO implements Serializable {

    public PcsSkuCategoryVO() {

    }

    private Long id;

    private Long parentId;

    private String name;

    private String code;

    private String fullName;

    private Integer isLeaf;

    private Integer inUse;

    private String attr;

    private Integer sort1;

    private Integer sort2;

    private String skucode;

    private String productName;

    // self

    private List<PcsSkuCategoryVO> children;

    private String type;

    // methods

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public Integer getIsLeaf() {
        return isLeaf;
    }

    public void setIsLeaf(Integer isLeaf) {
        this.isLeaf = isLeaf;
    }

    public Integer getInUse() {
        return inUse;
    }

    public void setInUse(Integer inUse) {
        this.inUse = inUse;
    }

    public List<PcsSkuCategoryVO> getChildren() {
        return children;
    }

    public void setChildren(List<PcsSkuCategoryVO> children) {
        this.children = children;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getAttr() {
        return attr;
    }

    public void setAttr(String attr) {
        this.attr = attr;
    }

    public Integer getSort1() {
        return sort1;
    }

    public void setSort1(Integer sort1) {
        this.sort1 = sort1;
    }

    public Integer getSort2() {
        return sort2;
    }

    public void setSort2(Integer sort2) {
        this.sort2 = sort2;
    }

    public String getSkucode() {
        return skucode;
    }

    public void setSkucode(String skucode) {
        this.skucode = skucode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 如果对象类型是User 的话 则返回true 去比较hashCode值
     */
    @Override
    public boolean equals(Object obj) {
        if(obj == null) return false;
        if(this == obj) return true;
        if(obj instanceof PcsSkuCategoryVO){
            PcsSkuCategoryVO user =(PcsSkuCategoryVO)obj;
//          if(user.id = this.id) return true; // 只比较id
            // 比较id 一致时才返回true 之后再去比较 hashCode
            if(user.id.longValue() == this.id.longValue()) return true;
        }
        return false;
    }



    /**
     * 重写hashcode 方法，返回的hashCode 不一样才认定为不同的对象
     */
    @Override
    public int hashCode() {
//      return id.hashCode(); // 只比较id，id一样就不添加进集合
        return id.hashCode();
    }
}

==> pegasus-merchandise-api-2.0.7-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuCategoryVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author Eric.Lou
 * @version $Id: JsTree.java, v 0.1 2015-07-30 16:50
 */
public class PcsSkuCategoryVO implements Serializable {

    public PcsSkuCategoryVO() {

    }

    private Long id;

    private Long parentId;

    private String name;

    private String code;

    private String fullName;

    private Integer isLeaf;

    private Integer inUse;

    private String attr;

    private Integer sort1;

    private Integer sort2;

    private String skucode;

    private String productName;

    // self

    private List<PcsSkuCategoryVO> children;

    private String type;

    //是否主分类
    private boolean whetherMain = false;

    // methods

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getFullName() {
        return fullName;
    }

    public void setFullName(String fullName) {
        this.fullName = fullName;
    }

    public Integer getIsLeaf() {
        return isLeaf;
    }

    public void setIsLeaf(Integer isLeaf) {
        this.isLeaf = isLeaf;
    }

    public Integer getInUse() {
        return inUse;
    }

    public void setInUse(Integer inUse) {
        this.inUse = inUse;
    }

    public List<PcsSkuCategoryVO> getChildren() {
        return children;
    }

    public void setChildren(List<PcsSkuCategoryVO> children) {
        this.children = children;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getAttr() {
        return attr;
    }

    public void setAttr(String attr) {
        this.attr = attr;
    }

    public Integer getSort1() {
        return sort1;
    }

    public void setSort1(Integer sort1) {
        this.sort1 = sort1;
    }

    public Integer getSort2() {
        return sort2;
    }

    public void setSort2(Integer sort2) {
        this.sort2 = sort2;
    }

    public String getSkucode() {
        return skucode;
    }

    public void setSkucode(String skucode) {
        this.skucode = skucode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 如果对象类型是User 的话 则返回true 去比较hashCode值
     */
    @Override
    public boolean equals(Object obj) {
        if(obj == null) return false;
        if(this == obj) return true;
        if(obj instanceof PcsSkuCategoryVO){
            PcsSkuCategoryVO user =(PcsSkuCategoryVO)obj;
//          if(user.id = this.id) return true; // 只比较id
            // 比较id 一致时才返回true 之后再去比较 hashCode
            if(user.id.longValue() == this.id.longValue()) return true;
        }
        return false;
    }



    /**
     * 重写hashcode 方法，返回的hashCode 不一样才认定为不同的对象
     */
    @Override
    public int hashCode() {
//      return id.hashCode(); // 只比较id，id一样就不添加进集合
        return id.hashCode();
    }

    public boolean isWhetherMain() {
        return whetherMain;
    }

    public void setWhetherMain(boolean whetherMain) {
        this.whetherMain = whetherMain;
    }
}
